==> nosql-database_24.4.zip: nosql-database_24.4_20241213/content/sqlfornosql/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-F8790625-B0DF-47B1-9C50-F87F76BC05E9"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Introduction to SQL for Oracle NoSQL Database",
                    "href":"introduction-sql.html"
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Simple SELECT Queries",
                    "href":"simple-select-where-queries.html",
                    "topics":[
                        {
                            "title":"SQLBasicExamples Script",
                            "href":"sqlbasicexamples-script.html"
                        },
                        {
                            "title":"Starting the SQL Shell",
                            "href":"starting-sql-shell.html"
                        },
                        {
                            "title":"Choosing column data",
                            "href":"selecting-columns.html"
                        },
                        {
                            "title":"Substituting column names for a query",
                            "href":"renaming-columns.html"
                        },
                        {
                            "title":"Computing values for new columns",
                            "href":"computing-new-columns.html"
                        },
                        {
                            "title":"Identifying tables and their columns",
                            "href":"identifying-tables-and-their-columns.html"
                        },
                        {
                            "title":"Filtering Results",
                            "href":"filtering-results.html"
                        },
                        {
                            "title":"Grouping Results",
                            "href":"grouping-results.html"
                        },
                        {
                            "title":"Ordering Results",
                            "href":"ordering-results.html"
                        },
                        {
                            "title":"Limiting and Offsetting Results",
                            "href":"limiting-and-offsetting-results.html"
                        },
                        {
                            "title":"Using External Variables",
                            "href":"using-external-variables.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Working with complex data",
                    "href":"working-complex-data.html",
                    "topics":[
                        {
                            "title":"SQLAdvancedExamples Script",
                            "href":"sqladvancedexamples-script.html"
                        },
                        {
                            "title":"Working with Timestamps",
                            "href":"working-timestamps.html"
                        },
                        {
                            "title":"Working With Arrays",
                            "href":"working-arrays.html"
                        },
                        {
                            "title":"Working with Records",
                            "href":"working-records.html"
                        },
                        {
                            "title":"Using ORDER BY to Sort Results",
                            "href":"using-order-sort-results.html"
                        },
                        {
                            "title":"Working With Maps",
                            "href":"working-maps.html"
                        },
                        {
                            "title":"Using the size() Function",
                            "href":"using-size-function.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Working with JSON",
                    "href":"working-json.html",
                    "topics":[
                        {
                            "title":"SQLJSONExamples Script",
                            "href":"sqljsonexamples-script.html"
                        },
                        {
                            "title":"Basic Queries",
                            "href":"basic-queries.html"
                        },
                        {
                            "title":"Using WHERE EXISTS with JSON",
                            "href":"using-exists-json.html"
                        },
                        {
                            "title":"Seeking NULLS in Arrays",
                            "href":"seeking-nulls-arrays.html"
                        },
                        {
                            "title":"Examining Data Types JSON Columns",
                            "href":"examining-data-types-json-columns.html"
                        },
                        {
                            "title":"Using Map Steps with JSON Data",
                            "href":"using-map-steps-json-data.html"
                        },
                        {
                            "title":"Casting Datatypes",
                            "href":"casting-datatypes.html"
                        },
                        {
                            "title":"Using Searched Case",
                            "href":"using-searched-case.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Working With GeoJSON Data",
                    "href":"working-geojson-data.html",
                    "topics":[
                        {
                            "title":"Geodetic Coordinates",
                            "href":"geodetic-coordinate-system.html"
                        },
                        {
                            "title":"GeoJSON Data Definitions",
                            "href":"geojson-data-definitions.html"
                        },
                        {
                            "title":"Searching GeoJSON Data",
                            "href":"searching-geojson-data.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Working With Indexes",
                    "href":"working-indexes.html",
                    "topics":[
                        {
                            "title":"Basic Indexing",
                            "href":"basic-indexing.html"
                        },
                        {
                            "title":"Using Index Hints",
                            "href":"using-index-hints.html"
                        },
                        {
                            "title":"Complex Indexes",
                            "href":"complex-indexes.html"
                        },
                        {
                            "title":"Multi-Key Indexes",
                            "href":"multi-key-indexes.html"
                        },
                        {
                            "title":"Indexing JSON Data",
                            "href":"indexing-json-data.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Working with Table Rows",
                    "href":"working-table-rows.html",
                    "topics":[
                        {
                            "title":"Adding Table Rows using INSERT and UPSERT",
                            "href":"adding-table-rows-using-insert-and-upsert-statements.html"
                        },
                        {
                            "title":"Modifying Table Rows using UPDATE Statements",
                            "href":"modifying-table-rows-using-update-statements.html#GUID-9CB20D0B-697F-4E0C-B041-3350A0A17B36"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">A </span> Introduction to the SQL for Oracle NoSQL Database Shell",
                    "href":"introduction-sql-shell.html",
                    "topics":[
                        {
                            "title":"Running the SQL Shell",
                            "href":"running-sql-shell.html"
                        },
                        {
                            "title":"Configuring the shell",
                            "href":"configuring-shell.html"
                        },
                        {
                            "title":"Shell Utility Commands",
                            "href":"shell-utility-commands.html#GUID-70FA12B5-6AD3-4965-9163-FA9549078EC7"
                        }
                    ]
                }
            ]
        }
    ]
});

==> nosql-database_25.3.zip: nosql-database_25.3_20251015/content/sqlfornosql/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-F8790625-B0DF-47B1-9C50-F87F76BC05E9"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Introduction to SQL for Oracle NoSQL Database",
                    "href":"introduction-sql.html"
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Working with Namesapce",
                    "href":"working-namespace.html",
                    "topics":[
                        {
                            "title":"Managing Namespace",
                            "href":"managing-namespace.html"
                        },
                        {
                            "title":"Namespace Resolution",
                            "href":"namespace-resolution.html"
                        },
                        {
                            "title":"Namespace Privileges and Authorization",
                            "href":"namespace-privileges-and-authorization.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Simple SELECT Queries",
                    "href":"simple-select-where-queries.html",
                    "topics":[
                        {
                            "title":"SQLBasicExamples Script",
                            "href":"sqlbasicexamples-script.html"
                        },
                        {
                            "title":"Starting the SQL Shell",
                            "href":"starting-sql-shell.html"
                        },
                        {
                            "title":"Choosing column data",
                            "href":"selecting-columns.html"
                        },
                        {
                            "title":"Substituting column names for a query",
                            "href":"renaming-columns.html"
                        },
                        {
                            "title":"Computing values for new columns",
                            "href":"computing-new-columns.html"
                        },
                        {
                            "title":"Identifying tables and their columns",
                            "href":"identifying-tables-and-their-columns.html"
                        },
                        {
                            "title":"Filtering Results",
                            "href":"filtering-results.html"
                        },
                        {
                            "title":"Grouping Results",
                            "href":"grouping-results.html"
                        },
                        {
                            "title":"Ordering Results",
                            "href":"ordering-results.html"
                        },
                        {
                            "title":"Limiting and Offsetting Results",
                            "href":"limiting-and-offsetting-results.html"
                        },
                        {
                            "title":"Using External Variables",
                            "href":"using-external-variables.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Working with complex data",
                    "href":"working-complex-data.html",
                    "topics":[
                        {
                            "title":"SQLAdvancedExamples Script",
                            "href":"sqladvancedexamples-script.html"
                        },
                        {
                            "title":"Working with Timestamps",
                            "href":"working-timestamps.html"
                        },
                        {
                            "title":"Working With Arrays",
                            "href":"working-arrays.html"
                        },
                        {
                            "title":"Working with Records",
                            "href":"working-records.html"
                        },
                        {
                            "title":"Using ORDER BY to Sort Results",
                            "href":"using-order-sort-results.html"
                        },
                        {
                            "title":"Working With Maps",
                            "href":"working-maps.html"
                        },
                        {
                            "title":"Using the size() Function",
                            "href":"using-size-function.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Working with JSON",
                    "href":"working-json.html",
                    "topics":[
                        {
                            "title":"SQLJSONExamples Script",
                            "href":"sqljsonexamples-script.html"
                        },
                        {
                            "title":"Basic Queries",
                            "href":"basic-queries.html"
                        },
                        {
                            "title":"Using WHERE EXISTS with JSON",
                            "href":"using-exists-json.html"
                        },
                        {
                            "title":"Seeking NULLS in Arrays",
                            "href":"seeking-nulls-arrays.html"
                        },
                        {
                            "title":"Examining Data Types JSON Columns",
                            "href":"examining-data-types-json-columns.html"
                        },
                        {
                            "title":"Using Map Steps with JSON Data",
                            "href":"using-map-steps-json-data.html"
                        },
                        {
                            "title":"Casting Datatypes",
                            "href":"casting-datatypes.html"
                        },
                        {
                            "title":"Using Searched Case",
                            "href":"using-searched-case.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">6 </span> Working with Expressions",
                    "href":"working-expressions.html",
                    "topics":[
                        {
                            "title":"Primary Expressions",
                            "href":"primary-expressions.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">7 </span> Working With GeoJSON Data",
                    "href":"working-geojson-data.html",
                    "topics":[
                        {
                            "title":"Geodetic Coordinates",
                            "href":"geodetic-coordinate-system.html"
                        },
                        {
                            "title":"GeoJSON Data Definitions",
                            "href":"geojson-data-definitions.html"
                        },
                        {
                            "title":"Searching GeoJSON Data",
                            "href":"searching-geojson-data.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">8 </span> Working With Indexes",
                    "href":"working-indexes.html",
                    "topics":[
                        {
                            "title":"Basic Indexing",
                            "href":"basic-indexing.html"
                        },
                        {
                            "title":"Using Index Hints",
                            "href":"using-index-hints.html"
                        },
                        {
                            "title":"Complex Indexes",
                            "href":"complex-indexes.html"
                        },
                        {
                            "title":"Multi-Key Indexes",
                            "href":"multi-key-indexes.html"
                        },
                        {
                            "title":"Indexing JSON Data",
                            "href":"indexing-json-data.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">9 </span> Working with Table Rows",
                    "href":"working-table-rows.html",
                    "topics":[
                        {
                            "title":"Adding Table Rows using INSERT and UPSERT",
                            "href":"adding-table-rows-using-insert-and-upsert-statements.html"
                        },
                        {
                            "title":"Modifying Table Rows using UPDATE Statements",
                            "href":"modifying-table-rows-using-update-statements.html#GUID-9CB20D0B-697F-4E0C-B041-3350A0A17B36"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">10 </span> Working with Multi-Region Setup",
                    "href":"working-multi-region-setup.html",
                    "topics":[
                        {
                            "title":"Managing Regions",
                            "href":"managing-regions.html"
                        },
                        {
                            "title":"Using MR_COUNTERs",
                            "href":"using-mr_counters.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">A </span> Introduction to the SQL for Oracle NoSQL Database Shell",
                    "href":"introduction-sql-shell.html",
                    "topics":[
                        {
                            "title":"Running the SQL Shell",
                            "href":"running-sql-shell.html"
                        },
                        {
                            "title":"Configuring the shell",
                            "href":"configuring-shell.html"
                        },
                        {
                            "title":"Shell Utility Commands",
                            "href":"shell-utility-commands.html#GUID-70FA12B5-6AD3-4965-9163-FA9549078EC7"
                        }
                    ]
                }
            ]
        }
    ]
});
